@@ -1,9 +1,13 @@
-from pydantic import BaseModel, Field
-from typing import Optional
+from typing import Any, List, Optional
+
+from pydantic import BaseModel
+
+from ..base_model import BaseResponseModel
 
 
 class LimitationConfiguration(BaseModel):
-    plan_codes: Optional[list]
+    plan_codes: Optional[List[Any]]
+    billable_metric_codes: Optional[List[Any]]
 
 
 class Coupon(BaseModel):
@@ -21,7 +25,7 @@ class Coupon(BaseModel):
     applies_to: Optional[LimitationConfiguration]
 
 
-class CouponResponse(BaseModel):
+class CouponResponse(BaseResponseModel):
     lago_id: str
     name: str
     code: str
@@ -35,5 +39,7 @@ class CouponResponse(BaseModel):
     reusable: Optional[bool]
     frequency: Optional[str]
     frequency_duration: Optional[int]
-    plan_codes: Optional[list]
+    plan_codes: Optional[List[Any]]
     limited_plans: Optional[bool]
+    billable_metric_codes: Optional[List[Any]]
+    limited_billable_metrics: Optional[bool]
